@@ -7,6 +7,6 @@
  * @since 3.0.0
  */
 
-require_once( dirname( __FILE__ ) . '/admin.php' );
+require_once __DIR__ . '/admin.php';
 
-wp_redirect( network_admin_url('settings.php') );
+wp_redirect( network_admin_url( 'settings.php' ) );
